# Scripts

The files in this directory are used to generate the documentation for the project.

- `generate_pypi_description.py`: Used for automatically generating the PyPI project page (`PYPI_DESCRIPTION.md`). Runs with `python scripts/generate_pypi_description.py`

- `readme_parser.py`: Helper functions for parsing the main README file.
